@@ -1,11 +1,11 @@
-# @(#)$Id: Functions.pm 248 2013-02-13 23:17:39Z pjf $
+# @(#)$Id: Functions.pm 253 2013-02-28 15:28:01Z pjf $
 
 package Class::Usul::Functions;
 
 use strict;
 use warnings;
 use feature      qw(state);
-use version; our $VERSION = qv( sprintf '0.12.%d', q$Rev: 248 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.12.%d', q$Rev: 253 $ =~ /\d+/gmx );
 
 use Class::Usul::Constants;
 use Data::Printer alias => q(Dumper), colored => 1, indent => 3,
@@ -21,7 +21,7 @@ use Path::Class::Dir;
 use Scalar::Util qw(blessed openhandle);
 use Sys::Hostname;
 
-my @_functions; my $_bson_id_inc : shared = 0; my $osname = lc $OSNAME;
+my @_functions; my $_bson_id_inc : shared = 0;
 
 BEGIN {
    @_functions = ( qw(abs_path app_prefix arg_list assert_directory
@@ -30,8 +30,8 @@ BEGIN {
                       data_dumper distname downgrade elapsed
                       env_prefix escape_TT exception find_source fold
                       fqdn hex2str home2appldir is_arrayref is_coderef
-                      is_hashref is_member merge_attributes my_prefix
-                      pad prefix2class product say split_on__
+                      is_hashref is_member is_win32 merge_attributes
+                      my_prefix pad prefix2class product say split_on__
                       split_on_dash squeeze strip_leader sub_name sum
                       thread_id throw trim unescape_TT untaint_cmdline
                       untaint_identifier untaint_path untaint_string
@@ -46,12 +46,12 @@ use Sub::Exporter -setup => {
 sub abs_path ($) {
    my $y = shift; (defined $y and length $y) or return $y;
 
-   ($osname eq EVIL or $osname eq q(cygwin))
+   (is_win32() or lc $OSNAME eq q(cygwin))
       and not -e $y and return untaint_path( $y ); # Hate
 
    $y = Cwd::abs_path( untaint_path( $y ) );
 
-   $osname eq EVIL and defined $y and $y =~ s{ / }{\\}gmx; # More hate
+   is_win32() and defined $y and $y =~ s{ / }{\\}gmx; # More hate
 
    return $y;
 }
@@ -218,6 +218,10 @@ sub is_member (;@) {
    return (first { $_ eq $candidate } @rest) ? 1 : 0;
 }
 
+sub is_win32 () {
+   return lc $OSNAME eq EVIL ? 1 : 0;
+}
+
 sub merge_attributes ($$$;$) {
    my ($dest, $src, $defaults, $attrs) = @_; my $class = blessed $src;
 
@@ -262,7 +266,7 @@ sub say (;@) {
 
    $rest[ 0 ] ||= q(); chomp( @rest );
 
-   local ($OFS, $ORS) = $osname eq EVIL ? ("\r\n", "\r\n") : ("\n", "\n");
+   local ($OFS, $ORS) = is_win32() ? ("\r\n", "\r\n") : ("\n", "\n");
 
    return print {*STDOUT} @rest
       or throw( error => 'IO error [_1]', args =>[ $ERRNO ] );
@@ -481,7 +485,7 @@ CatalystX::Usul::Functions - Globally accessible functions
 
 =head1 Version
 
-0.6.$Revision: 248 $
+0.6.$Revision: 253 $
 
 =head1 Synopsis
 
@@ -636,7 +640,7 @@ variables
 
 =head2 escape_TT
 
-   $text = escape_TT q([% some_stash_key %]);
+   $text = escape_TT '[% some_stash_key %]';
 
 The left square bracket causes problems in some contexts. Substitute a
 less than symbol instead. Also replaces the right square bracket with
@@ -705,6 +709,12 @@ Tests to see if the scalar variable is a hash ref
 Tests to see if the first parameter is present in the list of
 remaining parameters
 
+=head2 is_win32
+
+   $bool = is_win32;
+
+Returns true if the C<$OSNAME> is L<evil|Class::Usul::Constants/EVIL>
+
 =head2 merge_attributes
 
    $dest = merge_attributes $dest, $src, $defaults, $attr_list_ref;
@@ -739,7 +749,7 @@ C<ucfirst>s the list and then C<join>s that with I<::>
 
 =head2 product
 
-   $product = product( 1, 2, 3, 4 );
+   $product = product 1, 2, 3, 4;
 
 Returns the product of the list of numbers
 
@@ -766,13 +776,13 @@ to field zero
 
 =head2 squeeze
 
-   $string = squeeze $string_containing_muliple_spacesd);
+   $string = squeeze $string_containing_muliple_spacesd;
 
 Squeezes multiple whitespace down to a single space
 
 =head2 strip_leader
 
-   $stripped = strip_leader q(my_program: Error message);
+   $stripped = strip_leader 'my_program: Error message';
 
 Strips the leading "program_name: whitespace" from the passed argument
 
@@ -798,13 +808,13 @@ Returns the id of this thread. Returns zero if threads are not loaded
 
    throw error => q(error_key), args => [ q(error_arg) ];
 
-Expose L<CatalystX::Usul::Exception/throw>. C<CX::Usul::Functions> has a
-class attribute I<Exception_Class> which can be set via a call to
-C<set_inherited>
+Expose L<File::DataClass::Exception/throw>. L<Class::Usul::Constants> has a
+class attribute I<Exception_Class> which can be set change the class
+of the thrown exception
 
 =head2 trim
 
-   $trimmed_string = trim $string_with_leading_and trailing_whitespace;
+   $trimmed_string = trim $string_with_leading_and_trailing_whitespace;
 
 Remove leading and trailing whitespace including trailing newlines
 
@@ -843,7 +853,7 @@ Returns an untainted string or throws
 
 =head2 zip
 
-   %hash = zip @list_of_keys @list_of_values;
+   %hash = zip @list_of_keys, @list_of_values;
 
 Zips two list of equal size together to form a hash
 
